var timer_8h =
[
    [ "ITimerCallback", "classSteinberg_1_1ITimerCallback.html", "classSteinberg_1_1ITimerCallback" ],
    [ "Timer", "classSteinberg_1_1Timer.html", "classSteinberg_1_1Timer" ],
    [ "DisableDispatchingTimers", "classSteinberg_1_1DisableDispatchingTimers.html", "classSteinberg_1_1DisableDispatchingTimers" ],
    [ "CreateTimerFunc", "timer_8h.html#a4319ee5b75ba654ea27e72a9925da401", null ],
    [ "getTicks64", "timer_8h.html#accc64954e88f0a32add172d0189918dc", null ],
    [ "getTicksDuration", "timer_8h.html#a5eb6e497830d117c9591a9d18faa3816", null ],
    [ "getTicks", "timer_8h.html#ae994ceba61021313d4200996d46787f5", null ],
    [ "newTimerCallback", "timer_8h.html#af754042087ab79da3c3b0d08681e9a93", null ],
    [ "InjectCreateTimerFunction", "timer_8h.html#a849a1fe250eac0b91bcdbe70167d560c", null ]
];